package
Version:
v0.0.0-...-e64d7c6
Opens a new window with list of versions in this module.
Published: Jan 11, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package password generates a strong password from a hashed string.
type Generator interface {
Encrypt() string
}
Generator is the interface that creates a fixed length password.
New creates a new password.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.